@@ -5,8 +5,7 @@ import time
 import pandas as pd
 from .db import CorpsEval
 from krx_hj3415 import krx
-from util_hj3415 import utils
-from stock_core.nfscrapy import scraper
+from util_hj3415 import utils, noti
 from multiprocessing import Process, cpu_count, Queue
 
 import logging
@@ -58,16 +57,9 @@ class Eval:
 
     def __init__(self, code):
         self.code = code
-        try:
-            self.corp_eval_db = CorpsEval(code)
-            self.corp_eval_db.set_col('c101')
-            self.rc101 = self.corp_eval_db.get_recent()[0]
-        except StopIteration:
-            # 데이터베이스에 c101자료가 없는 경우는 직접 스크래핑을 시도한다.
-            scraper.run('c101', [code, ])
-            self.corp_eval_db = CorpsEval(code)
-            self.corp_eval_db.set_col('c101')
-            self.rc101 = self.corp_eval_db.get_recent()[0]
+        self.corp_eval_db = CorpsEval(code)
+        self.corp_eval_db.set_col('c101')
+        self.rc101 = self.corp_eval_db.get_recent()[0]
         logger.debug(f'rc101:{self.rc101}')
         self.name = self.rc101['종목명']
         self.marketcap = int(self.rc101['시가총액']) / 100000000
@@ -569,8 +561,8 @@ class Score:
 
 class ReportOne:
     """
-    Eval클래스와 Score클래스를 같이 계산하여 다양한 방식의 출력구조에 맞춰 형식을 반환한다.
-    즉 Eval과 Score를 외부에서 직적 사용할 필요없이 ReportOne클래스를 사용한다.
+    Eval 클래스와 Score 클래스를 같이 계산하여 다양한 방식의 출력구조에 맞춰 형식을 반환한다.
+    즉 Eval 과 Score 를 외부에서 직접 사용할 필요 없이 ReportOne 클래스를 사용한다.
     """
     seperate_line = '\n' + ('-' * 65) + '\n'
 
@@ -750,6 +742,7 @@ class ReportOne:
         }
 
     def for_table(self) -> dict:
+        # 장고에서 사용할 eval 테이블을 만들기 위해 각각의 레코드를 구성하는 함수
         logger.debug(f"code: {self.eval_dict['c101']['코드']}")
         logger.debug(f"PFCF : {self.eval_dict['mil']['가치지표']['PFCF']}")
         logger.debug(f"PCR : {self.eval_dict['mil']['가치지표']['PCR']}")
@@ -805,9 +798,6 @@ def make_eval_df_all() -> pd.DataFrame:
         divided_list = _split_list(entire_codes, wanted_parts=n)
         return n, divided_list
 
-    from stock_core.load_db import Settings
-    setting = Settings(echo=True)
-    setting.set_mongo(mongo_addr='mongodb://192.168.0.173:27017')
     codes = CorpsEval.get_all_codes_in_db()
 
     print('*' * 25, f"Eval all using multiprocess", '*' * 25)
@@ -832,3 +822,27 @@ def make_eval_df_all() -> pd.DataFrame:
     print(f'Total spent time : {round(time.time() - start_time, 2)} sec.')
     logger.debug(final_df)
     return final_df
+
+
+def eval_spac() -> tuple:
+    """
+    전체 스팩주를 평가하여 가격이 2000원 이하인 경우 yield한다.
+    :return: (code, name, price)
+    """
+    codes = CorpsEval.get_all_codes_in_db()
+    logger.debug(f'len(codes) : {len(codes)}')
+    print('<<< Finding valuable SPAC >>>')
+    for code in codes:
+        name = krx.get_name(code)
+        logger.debug(f'code : {code} name : {name}')
+        if '스팩' in str(name):
+            logger.debug(f'code : {code} name : {name}')
+            corp_eval_db = CorpsEval(code)
+            corp_eval_db.set_col('c101')
+            rc101 = corp_eval_db.get_recent()[0]
+            logger.debug(f'rc101:{rc101}')
+            if utils.to_int(rc101['주가']) <= 2000:
+                logger.warning(f'rc101:{rc101}')
+                print(f"code: {code} name: {name}, price: {rc101['주가']}")
+                yield code, name, rc101['주가']
+
